Crate eater

Crate eater 

Structs

Parser
Repeated
Spec
Used for speculative parsing. This allows you to peek at a char and optionally advance the parser that was peeked from.

Enums

MatchStatus
MatchStatus is used to control the parser state machine for parsing functions.

Functions

ascii_ident
match_any_char
match_between_repeated
match_char
match_exact
match_from_set
match_singleline_str_literal
next_char_with_len
This function expects that s is a non-empty string. It does not check for you, you will have to do that check yourself.
parse_until
A parse function that parses until either the end of the stream or the given character is met. Does not consume the match character.
parse_while
singleline_str_literal_matcher
whitespace